Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1124)

Unified Diff: third_party/WebKit/Source/core/style/SVGComputedStyle.cpp

Issue 2066563002: Rename StyleLayoutData to StyleGeometryData (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/style/SVGComputedStyle.cpp
diff --git a/third_party/WebKit/Source/core/style/SVGComputedStyle.cpp b/third_party/WebKit/Source/core/style/SVGComputedStyle.cpp
index 9a1937e9c9ac17cc87bceeaa51cb292ae2614b58..35be21707f76ed749c2ba59a24e98fc38fc29988 100644
--- a/third_party/WebKit/Source/core/style/SVGComputedStyle.cpp
+++ b/third_party/WebKit/Source/core/style/SVGComputedStyle.cpp
@@ -40,7 +40,7 @@ SVGComputedStyle::SVGComputedStyle()
stops = initialStyle->stops;
misc = initialStyle->misc;
inheritedResources = initialStyle->inheritedResources;
- layout = initialStyle->layout;
+ geometry = initialStyle->geometry;
resources = initialStyle->resources;
setBitDefaults();
@@ -55,7 +55,7 @@ SVGComputedStyle::SVGComputedStyle(CreateInitialType)
stops.init();
misc.init();
inheritedResources.init();
- layout.init();
+ geometry.init();
resources.init();
}
@@ -67,7 +67,7 @@ SVGComputedStyle::SVGComputedStyle(const SVGComputedStyle& other)
stops = other.stops;
misc = other.misc;
inheritedResources = other.inheritedResources;
- layout = other.layout;
+ geometry = other.geometry;
resources = other.resources;
svg_inherited_flags = other.svg_inherited_flags;
@@ -85,7 +85,7 @@ bool SVGComputedStyle::operator==(const SVGComputedStyle& other) const
&& stops == other.stops
&& misc == other.misc
&& inheritedResources == other.inheritedResources
- && layout == other.layout
+ && geometry == other.geometry
&& resources == other.resources
&& svg_inherited_flags == other.svg_inherited_flags
&& svg_noninherited_flags == other.svg_noninherited_flags;
@@ -116,7 +116,7 @@ void SVGComputedStyle::copyNonInheritedFromCached(const SVGComputedStyle* other)
svg_noninherited_flags = other->svg_noninherited_flags;
stops = other->stops;
misc = other->misc;
- layout = other->layout;
+ geometry = other->geometry;
resources = other->resources;
}
@@ -185,8 +185,8 @@ bool SVGComputedStyle::diffNeedsLayoutAndPaintInvalidation(const SVGComputedStyl
return true;
}
- // The StyleLayoutData properties require a re-layout.
- if (layout.get() != other->layout.get() && *layout != *other->layout)
+ // The geometry properties require a re-layout.
+ if (geometry.get() != other->geometry.get() && *geometry != *other->geometry)
return true;
return false;
« no previous file with comments | « third_party/WebKit/Source/core/style/SVGComputedStyle.h ('k') | third_party/WebKit/Source/core/style/SVGComputedStyleDefs.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698